try:
    from ._version import version as __version__
except ImportError:
    __version__ = "unknown"



from ._reader import napari_get_reader, OperaPhenixReader
from ._widget import PhenixDataLoaderWidget

__all__ = (
    "napari_get_reader",
    "OperaPhenixReader",
    "PhenixDataLoaderWidget",
)
